==> apache-ranger-incubating-0.5.3.tar.gz: apache-ranger-incubating-0.5.3/hdfs-agent/src/main/java/org/apache/ranger/services/hdfs/RangerServiceHdfs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ranger.services.hdfs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.ranger.plugin.model.RangerService;
import org.apache.ranger.plugin.model.RangerServiceDef;
import org.apache.ranger.plugin.service.RangerBaseService;
import org.apache.ranger.plugin.service.ResourceLookupContext;
import org.apache.ranger.services.hdfs.client.HdfsResourceMgr;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class RangerServiceHdfs extends RangerBaseService {

	private static final Log LOG = LogFactory.getLog(RangerServiceHdfs.class);
	
	public RangerServiceHdfs() {
		super();
	}
	
	@Override
	public void init(RangerServiceDef serviceDef, RangerService service) {
		super.init(serviceDef, service);
	}

	@Override
	public HashMap<String,Object> validateConfig() throws Exception {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		String 	serviceName  	    = getServiceName();
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.validateConfig Service: (" + serviceName + " )");
		}
		
		if ( configs != null) {
			try  {
				ret = HdfsResourceMgr.testConnection(serviceName, configs);
			} catch (Exception e) {
				LOG.error("<== RangerServiceHdfs.validateConfig Error:" + e);
				throw e;
			}
		}
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.validateConfig Response : (" + ret + " )");
		}
		
		return ret;
	}

	@Override
	public List<String> lookupResource(ResourceLookupContext context) throws Exception {
		List<String> ret = new ArrayList<String>();
		String 	serviceName  	   = getServiceName();
		String	serviceType		   = getServiceType();
		Map<String,String> configs = getConfigs();
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.lookupResource Context: (" + context + ")");
		}
		
		if (context != null) {
			try {
				ret  = HdfsResourceMgr.getHdfsResources(serviceName, serviceType, configs,context);
			} catch (Exception e) {
			  LOG.error( "<==RangerServiceHdfs.lookupResource Error : " + e);
			  throw e;
			}
		}
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.lookupResource Response: (" + ret + ")");
		}
		
		return ret;
	}
}

==> apache-ranger-incubating-0.6.2.tar.gz: apache-ranger-incubating-0.6.2/hdfs-agent/src/main/java/org/apache/ranger/services/hdfs/RangerServiceHdfs.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ranger.services.hdfs;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.ranger.plugin.client.HadoopException;
import org.apache.ranger.plugin.model.RangerService;
import org.apache.ranger.plugin.model.RangerServiceDef;
import org.apache.ranger.plugin.service.RangerBaseService;
import org.apache.ranger.plugin.service.ResourceLookupContext;
import org.apache.ranger.services.hdfs.client.HdfsResourceMgr;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

public class RangerServiceHdfs extends RangerBaseService {

	private static final Log LOG = LogFactory.getLog(RangerServiceHdfs.class);
	
	public RangerServiceHdfs() {
		super();
	}
	
	@Override
	public void init(RangerServiceDef serviceDef, RangerService service) {
		super.init(serviceDef, service);
	}

	@Override
	public HashMap<String,Object> validateConfig() throws Exception {
		HashMap<String, Object> ret = new HashMap<String, Object>();
		String 	serviceName  	    = getServiceName();
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.validateConfig Service: (" + serviceName + " )");
		}
		
		if ( configs != null) {
			try  {
				ret = HdfsResourceMgr.connectionTest(serviceName, configs);
			} catch (HadoopException e) {
				LOG.error("<== RangerServiceHdfs.validateConfig Error: " + e.getMessage(),e);
				throw e;
			}
		}
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.validateConfig Response : (" + ret + " )");
		}
		
		return ret;
	}

	@Override
	public List<String> lookupResource(ResourceLookupContext context) throws Exception {
		List<String> ret = new ArrayList<String>();
		String 	serviceName  	   = getServiceName();
		String	serviceType		   = getServiceType();
		Map<String,String> configs = getConfigs();
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.lookupResource Context: (" + context + ")");
		}
		
		if (context != null) {
			try {
				ret  = HdfsResourceMgr.getHdfsResources(serviceName, serviceType, configs,context);
			} catch (Exception e) {
			  LOG.error( "<==RangerServiceHdfs.lookupResource Error : " + e);
			  throw e;
			}
		}
		
		if(LOG.isDebugEnabled()) {
			LOG.debug("<== RangerServiceHdfs.lookupResource Response: (" + ret + ")");
		}
		
		return ret;
	}
}
